@@ -67,11 +67,15 @@ class Animate:
         self.displaylist = []
 
         if axes is None:
-            # create an axes
+            # no axes specified
+
             fig = plt.gcf()
+            # check any current axes
             for a in fig.axes:
                 if a.name != "3d":
-                    fig.delete(a)
+                    # if they are not 3D axes, remove them, otherwise will 
+                    # get plot errors
+                    a.remove()
             if len(fig.axes) == 0:
                 # no axes in the figure, create a 3D axes
                 axes = fig.add_subplot(111, projection='3d', proj_type=projection)
