@@ -84,7 +84,7 @@ def trot2(theta, unit='rad', t=None):
     T = np.pad(rot2(theta, unit), (0, 1), mode='constant')
     if t is not None:
         T[:2, 2] = base.getvector(t, 2, 'array')
-    T[2, 2] = 1.0
+    T[2, 2] = 1  # integer to be symbolic friendly
     return T
 
 def xyt2tr(xyt, unit='rad'):
@@ -193,9 +193,10 @@ def transl2(x, y=None):
         function.
     """
 
-    if np.isscalar(x):
-        T = np.identity(3)
-        T[:2, 2] = [x, y]
+    if base.isscalar(x):
+        t = np.r_[x, y]
+        T = np.identity(3, dtype=t.dtype)
+        T[:2, 2] = t
         return T
     elif base.isvector(x, 2):
         T = np.identity(3)
@@ -204,7 +205,7 @@ def transl2(x, y=None):
     elif base.ismatrix(x, (3, 3)):
         return x[:2, 2]
     else:
-        ValueError('bad argument')
+        raise ValueError('bad argument')
 
 
 def ishom2(T, check=False):
@@ -495,6 +496,39 @@ def adjoint2(T):
     else:
         raise ValueError('bad argument')
 
+def tr2jac2(T):
+    r"""
+    SE(2) Jacobian matrix
+
+    :param T: SE(2) matrix
+    :type T: ndarray(3,3)
+    :return: Jacobian matrix
+    :rtype: ndarray(3,3)
+
+    Computes an Jacobian matrix that maps spatial velocity between two frames defined by
+    an SE(2) matrix.
+
+    ``tr2jac2(T)`` is a Jacobian matrix (3x3) that maps spatial velocity or
+    differential motion from frame {B} to frame {A} where the pose of {B}
+    elative to {A} is represented by the homogeneous transform T = :math:`{}^A {\bf T}_B`.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> T = trot2(0.3, t=[4,5])
+        >>> tr2jac2(T)
+    
+    :Reference: Robotics, Vision & Control: Second Edition, P. Corke, Springer 2016; p65.
+    :SymPy: supported
+    """
+
+    if not ishom2(T):
+        raise ValueError("expecting an SE(2) matrix")
+
+    J = np.eye(3, dtype=T.dtype)
+    J[:2,:2] = base.t2r(T)
+    return J
+
 def trinterp2(start, end, s=None):
     """
     Interpolate SE(2) or SO(2) matrices
