@@ -619,6 +619,55 @@ class SO3(SMPose):
         else:
             return cls(base.trexp(S, check=check), check=False)
 
+    def angdist(self, other, metric=3):
+        r"""
+        Angular distance metric between unit quaternions
+
+        :param other: second unit quaternion
+        :type other: UnitQuaternion instance
+        :param metric: metric, default is 3
+        :type metric: int
+        :raises TypeError: if other is not a UnitQuaternion
+        :return: angle in radians
+        :rtype: float
+
+        ``q1.angdist(q2)`` is the geodesic norm, or geodesic distance between two
+        unit quaternions.  We can consider it as the angle between two quaternions.
+
+        Several metrics are supported:
+
+        ======   ===============================================================
+        Metric   Details
+        ======   ===============================================================
+        0        :math:`1 - | \q_1 \bullet \q_2 | \in [0, 1]`
+        1        :math:`\cos^{-1} | \q_1 \bullet \q_2 | \in [0, \pi/2]`
+        2        :math:`\cos^{-1} | \q_1 \bullet \q_2 | \in [0, \pi/2]`
+        3        :math:`2 \tan^{-1} \| \q_1 - \q_2\| / \|\q_1 + \q_2\| \in [0, \pi/2]`
+        4        :math:`\cos^{-1} \left( 2 (\q_1 \bullet \q_2)^2 - 1\right) \in [0, 1]`
+        ======   ===============================================================
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import UnitQuaternion
+            >>> q1 = UnitQuaternion.Rx(0.3)
+            >>> q2 = UnitQuaternion.Ry(0.3)
+            >>> print(q1.angdist(q1))
+            >>> print(q1.angdist(q2))
+
+        .. note::
+            - metrics 1, 2, 4 can throw ValueError "math domain error" due to
+              numeric errors which push the argument of ``acos()`` marginally
+              outside its domain [0, 1].
+            - metrics 2 and 3 are equivalent, but 3 is more robust
+            - SMTB-MATLAB uses metric 3 for UnitQuaternion.angle()
+            - MATLAB's quaternion.dist() uses metric 4
+        """
+        from spatialmath.quaternion import UnitQuaternion
+
+        return UnitQuaternion(self).angdist(UnitQuaternion(other), metric=metric)
+
 # ============================== SE3 =====================================#
 
 
@@ -990,7 +1039,7 @@ class SE3(SO3):
         return cls([base.trotz(x, t=t, unit=unit) for x in base.getvector(theta)], check=False)
 
     @classmethod
-    def Rand(cls, *, xrange=(-1, 1), yrange=(-1, 1), zrange=(-1, 1), N=1):  # pylint: disable=arguments-differ
+    def Rand(cls, N=1, xrange=(-1, 1), yrange=(-1, 1), zrange=(-1, 1)):  # pylint: disable=arguments-differ
         """
         Create a random SE(3)
 
@@ -1008,12 +1057,12 @@ class SE3(SO3):
         Return an SE3 instance with random rotation and translation.
 
         - ``SE3.Rand()`` is a random SE(3) translation.
-        - ``SE3.Rand(N=N)`` is an SE3 object containing a sequence of N random
+        - ``SE3.Rand(N)`` is an SE3 object containing a sequence of N random
           poses.
 
         Example::
 
-            >>> SE3.Rand(N=2)
+            >>> SE3.Rand(2)
             SE3([
             array([[ 0.58076657,  0.64578702, -0.49565041, -0.78585825],
                 [-0.57373134, -0.10724881, -0.8119914 ,  0.72069253],
@@ -1269,7 +1318,7 @@ class SE3(SO3):
         :seealso: :func:`~delta`, :func:`~spatialmath.base.transform3d.delta2tr`
         :SymPy: supported
         """
-        return cls(base.delta2tr(d))
+        return cls(base.trnorm(base.delta2tr(d)))
 
     @classmethod
     def Tx(cls, x):
