@@ -556,6 +556,7 @@ class SMPose(SMUserList):
 
         :SymPy: supported
         """
+
         vf = np.vectorize(sym.simplify)
         return self.__class__([vf(x) for x in self.data], check=False)
 
@@ -664,14 +665,13 @@ class SMPose(SMUserList):
 
         """
         # see https://ipython.org/ipython-doc/stable/api/generated/IPython.lib.pretty.html
-        s = str(self).split('\n')
-        p.begin_group(4, self.__class__.__name__ + ':' +  s[0])
-        p.break_()
-        for i, s in enumerate(s[1:]):
-            p.text(s)
-            if i < len(s) - 2:
-                p.break_()
-        p.end_group(4, '')
+        
+        if len(self) == 1:
+            p.text(str(self))
+        else:
+            for i, x in enumerate(self):
+                p.text(f"{i}:\n{str(x)}")
+                
 
     def __str__(self):
         """
